Welcome to pyRserve’s documentation! — pyRserve v0.4 documentation

### Navigation

- index
- next |
- pyRserve v0.4 documentation »

# Welcome to pyRserve’s documentation!

pyRServe is a library for connecting Python to an R process running under Rserve. Through such a connection variables can be get and set in R from Python, and also R-functions can be called remotely.

This documentation applies to pyRserve V 0.4

Contents:

- pyRserve
  - What It Does
  - Changes
  - Supported Platforms
  - License
  - Quick Installation
  - Full Documentation
- Installation
  - Installing R from sources
  - Installing Rserve
  - Installing PyRserve
- pyRserve manual
  - Setting up a connection to Rserve
  - String evaluation in R
  - The R namespace
- This is the MIT license

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- pyRserve v0.4 documentation »